socialproto

package module
v0.0.0-...-966a8e8 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 21, 2024 License: GPL-3.0 Imports: 8 Imported by: 1

README

socialproto

protobuf files for social app

Documentation

Index

Constants

This section is empty.

Variables

var ComposePost_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "socialproto.ComposePost",
	HandlerType: (*ComposePostServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "ComposePost",
			Handler:    _ComposePost_ComposePost_Handler,
		},
		{
			MethodName: "ComposePostMulti",
			Handler:    _ComposePost_ComposePostMulti_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "compose_post.proto",
}

ComposePost_ServiceDesc is the grpc.ServiceDesc for ComposePost service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var File_compose_post_proto protoreflect.FileDescriptor
var File_home_timeline_proto protoreflect.FileDescriptor
var File_nginx_proto protoreflect.FileDescriptor
var File_post_storage_proto protoreflect.FileDescriptor
var File_social_graph_proto protoreflect.FileDescriptor
var File_user_timeline_proto protoreflect.FileDescriptor
var HomeTimeline_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "socialproto.HomeTimeline",
	HandlerType: (*HomeTimelineServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "ReadHomeTimeline",
			Handler:    _HomeTimeline_ReadHomeTimeline_Handler,
		},
		{
			MethodName: "WriteHomeTimeline",
			Handler:    _HomeTimeline_WriteHomeTimeline_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "home_timeline.proto",
}

HomeTimeline_ServiceDesc is the grpc.ServiceDesc for HomeTimeline service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var NginxService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "socialproto.NginxService",
	HandlerType: (*NginxServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "ComposePost",
			Handler:    _NginxService_ComposePost_Handler,
		},
		{
			MethodName: "ReadUserTimeline",
			Handler:    _NginxService_ReadUserTimeline_Handler,
		},
		{
			MethodName: "ReadHomeTimeline",
			Handler:    _NginxService_ReadHomeTimeline_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "nginx.proto",
}

NginxService_ServiceDesc is the grpc.ServiceDesc for NginxService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var PostStorage_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "socialproto.PostStorage",
	HandlerType: (*PostStorageServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "StorePost",
			Handler:    _PostStorage_StorePost_Handler,
		},
		{
			MethodName: "StorePostMulti",
			Handler:    _PostStorage_StorePostMulti_Handler,
		},
		{
			MethodName: "ReadPost",
			Handler:    _PostStorage_ReadPost_Handler,
		},
		{
			MethodName: "ReadPosts",
			Handler:    _PostStorage_ReadPosts_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "post_storage.proto",
}

PostStorage_ServiceDesc is the grpc.ServiceDesc for PostStorage service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var SocialGraph_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "socialproto.SocialGraph",
	HandlerType: (*SocialGraphServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "InsertUser",
			Handler:    _SocialGraph_InsertUser_Handler,
		},
		{
			MethodName: "GetFollowers",
			Handler:    _SocialGraph_GetFollowers_Handler,
		},
		{
			MethodName: "GetFollowees",
			Handler:    _SocialGraph_GetFollowees_Handler,
		},
		{
			MethodName: "Follow",
			Handler:    _SocialGraph_Follow_Handler,
		},
		{
			MethodName: "FollowMany",
			Handler:    _SocialGraph_FollowMany_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "social_graph.proto",
}

SocialGraph_ServiceDesc is the grpc.ServiceDesc for SocialGraph service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var UserTimeline_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "socialproto.UserTimeline",
	HandlerType: (*UserTimelineServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "ReadUserTimeline",
			Handler:    _UserTimeline_ReadUserTimeline_Handler,
		},
		{
			MethodName: "WriteUserTimeline",
			Handler:    _UserTimeline_WriteUserTimeline_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "user_timeline.proto",
}

UserTimeline_ServiceDesc is the grpc.ServiceDesc for UserTimeline service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterComposePostServer

func RegisterComposePostServer(s grpc.ServiceRegistrar, srv ComposePostServer)

func RegisterHomeTimelineServer

func RegisterHomeTimelineServer(s grpc.ServiceRegistrar, srv HomeTimelineServer)

func RegisterNginxServiceServer

func RegisterNginxServiceServer(s grpc.ServiceRegistrar, srv NginxServiceServer)

func RegisterPostStorageServer

func RegisterPostStorageServer(s grpc.ServiceRegistrar, srv PostStorageServer)

func RegisterSocialGraphServer

func RegisterSocialGraphServer(s grpc.ServiceRegistrar, srv SocialGraphServer)

func RegisterUserTimelineServer

func RegisterUserTimelineServer(s grpc.ServiceRegistrar, srv UserTimelineServer)

Types

type ComposePostClient

type ComposePostClient interface {
	ComposePost(ctx context.Context, in *ComposePostRequest, opts ...grpc.CallOption) (*ComposePostResponse, error)
	ComposePostMulti(ctx context.Context, in *ComposePostMultiRequest, opts ...grpc.CallOption) (*ComposePostMultiResponse, error)
}

ComposePostClient is the client API for ComposePost service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type ComposePostMultiRequest

type ComposePostMultiRequest struct {
	CreatorId string `protobuf:"bytes,1,opt,name=creator_id,json=creatorId,proto3" json:"creator_id,omitempty"`
	Text      string `protobuf:"bytes,2,opt,name=text,proto3" json:"text,omitempty"`
	Number    int32  `protobuf:"varint,3,opt,name=number,proto3" json:"number,omitempty"`
	// contains filtered or unexported fields
}

func (*ComposePostMultiRequest) Descriptor deprecated

func (*ComposePostMultiRequest) Descriptor() ([]byte, []int)

Deprecated: Use ComposePostMultiRequest.ProtoReflect.Descriptor instead.

func (*ComposePostMultiRequest) GetCreatorId

func (x *ComposePostMultiRequest) GetCreatorId() string

func (*ComposePostMultiRequest) GetNumber

func (x *ComposePostMultiRequest) GetNumber() int32

func (*ComposePostMultiRequest) GetText

func (x *ComposePostMultiRequest) GetText() string

func (*ComposePostMultiRequest) ProtoMessage

func (*ComposePostMultiRequest) ProtoMessage()

func (*ComposePostMultiRequest) ProtoReflect

func (x *ComposePostMultiRequest) ProtoReflect() protoreflect.Message

func (*ComposePostMultiRequest) Reset

func (x *ComposePostMultiRequest) Reset()

func (*ComposePostMultiRequest) String

func (x *ComposePostMultiRequest) String() string

type ComposePostMultiResponse

type ComposePostMultiResponse struct {
	PostIds []string `protobuf:"bytes,1,rep,name=post_ids,json=postIds,proto3" json:"post_ids,omitempty"`
	// contains filtered or unexported fields
}

func (*ComposePostMultiResponse) Descriptor deprecated

func (*ComposePostMultiResponse) Descriptor() ([]byte, []int)

Deprecated: Use ComposePostMultiResponse.ProtoReflect.Descriptor instead.

func (*ComposePostMultiResponse) GetPostIds

func (x *ComposePostMultiResponse) GetPostIds() []string

func (*ComposePostMultiResponse) ProtoMessage

func (*ComposePostMultiResponse) ProtoMessage()

func (*ComposePostMultiResponse) ProtoReflect

func (x *ComposePostMultiResponse) ProtoReflect() protoreflect.Message

func (*ComposePostMultiResponse) Reset

func (x *ComposePostMultiResponse) Reset()

func (*ComposePostMultiResponse) String

func (x *ComposePostMultiResponse) String() string

type ComposePostRequest

type ComposePostRequest struct {
	CreatorId string `protobuf:"bytes,1,opt,name=creator_id,json=creatorId,proto3" json:"creator_id,omitempty"`
	Text      string `protobuf:"bytes,2,opt,name=text,proto3" json:"text,omitempty"`
	// contains filtered or unexported fields
}

func (*ComposePostRequest) Descriptor deprecated

func (*ComposePostRequest) Descriptor() ([]byte, []int)

Deprecated: Use ComposePostRequest.ProtoReflect.Descriptor instead.

func (*ComposePostRequest) GetCreatorId

func (x *ComposePostRequest) GetCreatorId() string

func (*ComposePostRequest) GetText

func (x *ComposePostRequest) GetText() string

func (*ComposePostRequest) ProtoMessage

func (*ComposePostRequest) ProtoMessage()

func (*ComposePostRequest) ProtoReflect

func (x *ComposePostRequest) ProtoReflect() protoreflect.Message

func (*ComposePostRequest) Reset

func (x *ComposePostRequest) Reset()

func (*ComposePostRequest) String

func (x *ComposePostRequest) String() string

type ComposePostResponse

type ComposePostResponse struct {
	PostId string `protobuf:"bytes,1,opt,name=post_id,json=postId,proto3" json:"post_id,omitempty"`
	// contains filtered or unexported fields
}

func (*ComposePostResponse) Descriptor deprecated

func (*ComposePostResponse) Descriptor() ([]byte, []int)

Deprecated: Use ComposePostResponse.ProtoReflect.Descriptor instead.

func (*ComposePostResponse) GetPostId

func (x *ComposePostResponse) GetPostId() string

func (*ComposePostResponse) ProtoMessage

func (*ComposePostResponse) ProtoMessage()

func (*ComposePostResponse) ProtoReflect

func (x *ComposePostResponse) ProtoReflect() protoreflect.Message

func (*ComposePostResponse) Reset

func (x *ComposePostResponse) Reset()

func (*ComposePostResponse) String

func (x *ComposePostResponse) String() string

type ComposePostServer

type ComposePostServer interface {
	ComposePost(context.Context, *ComposePostRequest) (*ComposePostResponse, error)
	ComposePostMulti(context.Context, *ComposePostMultiRequest) (*ComposePostMultiResponse, error)
	// contains filtered or unexported methods
}

ComposePostServer is the server API for ComposePost service. All implementations must embed UnimplementedComposePostServer for forward compatibility

type FollowManyRequest

type FollowManyRequest struct {
	UserId      string   `protobuf:"bytes,1,opt,name=user_id,json=userId,proto3" json:"user_id,omitempty"`
	FollowerIds []string `protobuf:"bytes,2,rep,name=follower_ids,json=followerIds,proto3" json:"follower_ids,omitempty"`
	FolloweeIds []string `protobuf:"bytes,3,rep,name=followee_ids,json=followeeIds,proto3" json:"followee_ids,omitempty"`
	// contains filtered or unexported fields
}

func (*FollowManyRequest) Descriptor deprecated

func (*FollowManyRequest) Descriptor() ([]byte, []int)

Deprecated: Use FollowManyRequest.ProtoReflect.Descriptor instead.

func (*FollowManyRequest) GetFolloweeIds

func (x *FollowManyRequest) GetFolloweeIds() []string

func (*FollowManyRequest) GetFollowerIds

func (x *FollowManyRequest) GetFollowerIds() []string

func (*FollowManyRequest) GetUserId

func (x *FollowManyRequest) GetUserId() string

func (*FollowManyRequest) ProtoMessage

func (*FollowManyRequest) ProtoMessage()

func (*FollowManyRequest) ProtoReflect

func (x *FollowManyRequest) ProtoReflect() protoreflect.Message

func (*FollowManyRequest) Reset

func (x *FollowManyRequest) Reset()

func (*FollowManyRequest) String

func (x *FollowManyRequest) String() string

type FollowManyResponse

type FollowManyResponse struct {
	Success bool `protobuf:"varint,1,opt,name=success,proto3" json:"success,omitempty"`
	// contains filtered or unexported fields
}

func (*FollowManyResponse) Descriptor deprecated

func (*FollowManyResponse) Descriptor() ([]byte, []int)

Deprecated: Use FollowManyResponse.ProtoReflect.Descriptor instead.

func (*FollowManyResponse) GetSuccess

func (x *FollowManyResponse) GetSuccess() bool

func (*FollowManyResponse) ProtoMessage

func (*FollowManyResponse) ProtoMessage()

func (*FollowManyResponse) ProtoReflect

func (x *FollowManyResponse) ProtoReflect() protoreflect.Message

func (*FollowManyResponse) Reset

func (x *FollowManyResponse) Reset()

func (*FollowManyResponse) String

func (x *FollowManyResponse) String() string

type FollowRequest

type FollowRequest struct {
	FollowerId string `protobuf:"bytes,1,opt,name=follower_id,json=followerId,proto3" json:"follower_id,omitempty"`
	FolloweeId string `protobuf:"bytes,2,opt,name=followee_id,json=followeeId,proto3" json:"followee_id,omitempty"`
	// contains filtered or unexported fields
}

func (*FollowRequest) Descriptor deprecated

func (*FollowRequest) Descriptor() ([]byte, []int)

Deprecated: Use FollowRequest.ProtoReflect.Descriptor instead.

func (*FollowRequest) GetFolloweeId

func (x *FollowRequest) GetFolloweeId() string

func (*FollowRequest) GetFollowerId

func (x *FollowRequest) GetFollowerId() string

func (*FollowRequest) ProtoMessage

func (*FollowRequest) ProtoMessage()

func (*FollowRequest) ProtoReflect

func (x *FollowRequest) ProtoReflect() protoreflect.Message

func (*FollowRequest) Reset

func (x *FollowRequest) Reset()

func (*FollowRequest) String

func (x *FollowRequest) String() string

type FollowResponse

type FollowResponse struct {
	Success bool `protobuf:"varint,1,opt,name=success,proto3" json:"success,omitempty"`
	// contains filtered or unexported fields
}

func (*FollowResponse) Descriptor deprecated

func (*FollowResponse) Descriptor() ([]byte, []int)

Deprecated: Use FollowResponse.ProtoReflect.Descriptor instead.

func (*FollowResponse) GetSuccess

func (x *FollowResponse) GetSuccess() bool

func (*FollowResponse) ProtoMessage

func (*FollowResponse) ProtoMessage()

func (*FollowResponse) ProtoReflect

func (x *FollowResponse) ProtoReflect() protoreflect.Message

func (*FollowResponse) Reset

func (x *FollowResponse) Reset()

func (*FollowResponse) String

func (x *FollowResponse) String() string

type GetFolloweesRequest

type GetFolloweesRequest struct {
	UserId string `protobuf:"bytes,1,opt,name=user_id,json=userId,proto3" json:"user_id,omitempty"`
	// contains filtered or unexported fields
}

func (*GetFolloweesRequest) Descriptor deprecated

func (*GetFolloweesRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetFolloweesRequest.ProtoReflect.Descriptor instead.

func (*GetFolloweesRequest) GetUserId

func (x *GetFolloweesRequest) GetUserId() string

func (*GetFolloweesRequest) ProtoMessage

func (*GetFolloweesRequest) ProtoMessage()

func (*GetFolloweesRequest) ProtoReflect

func (x *GetFolloweesRequest) ProtoReflect() protoreflect.Message

func (*GetFolloweesRequest) Reset

func (x *GetFolloweesRequest) Reset()

func (*GetFolloweesRequest) String

func (x *GetFolloweesRequest) String() string

type GetFolloweesResponse

type GetFolloweesResponse struct {
	Followees []string `protobuf:"bytes,1,rep,name=followees,proto3" json:"followees,omitempty"`
	// contains filtered or unexported fields
}

func (*GetFolloweesResponse) Descriptor deprecated

func (*GetFolloweesResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetFolloweesResponse.ProtoReflect.Descriptor instead.

func (*GetFolloweesResponse) GetFollowees

func (x *GetFolloweesResponse) GetFollowees() []string

func (*GetFolloweesResponse) ProtoMessage

func (*GetFolloweesResponse) ProtoMessage()

func (*GetFolloweesResponse) ProtoReflect

func (x *GetFolloweesResponse) ProtoReflect() protoreflect.Message

func (*GetFolloweesResponse) Reset

func (x *GetFolloweesResponse) Reset()

func (*GetFolloweesResponse) String

func (x *GetFolloweesResponse) String() string

type GetFollowersRequest

type GetFollowersRequest struct {
	UserId string `protobuf:"bytes,1,opt,name=user_id,json=userId,proto3" json:"user_id,omitempty"`
	// contains filtered or unexported fields
}

func (*GetFollowersRequest) Descriptor deprecated

func (*GetFollowersRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetFollowersRequest.ProtoReflect.Descriptor instead.

func (*GetFollowersRequest) GetUserId

func (x *GetFollowersRequest) GetUserId() string

func (*GetFollowersRequest) ProtoMessage

func (*GetFollowersRequest) ProtoMessage()

func (*GetFollowersRequest) ProtoReflect

func (x *GetFollowersRequest) ProtoReflect() protoreflect.Message

func (*GetFollowersRequest) Reset

func (x *GetFollowersRequest) Reset()

func (*GetFollowersRequest) String

func (x *GetFollowersRequest) String() string

type GetFollowersResponse

type GetFollowersResponse struct {
	Followers []string `protobuf:"bytes,1,rep,name=followers,proto3" json:"followers,omitempty"`
	// contains filtered or unexported fields
}

func (*GetFollowersResponse) Descriptor deprecated

func (*GetFollowersResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetFollowersResponse.ProtoReflect.Descriptor instead.

func (*GetFollowersResponse) GetFollowers

func (x *GetFollowersResponse) GetFollowers() []string

func (*GetFollowersResponse) ProtoMessage

func (*GetFollowersResponse) ProtoMessage()

func (*GetFollowersResponse) ProtoReflect

func (x *GetFollowersResponse) ProtoReflect() protoreflect.Message

func (*GetFollowersResponse) Reset

func (x *GetFollowersResponse) Reset()

func (*GetFollowersResponse) String

func (x *GetFollowersResponse) String() string

type HomeTimelineClient

type HomeTimelineClient interface {
	ReadHomeTimeline(ctx context.Context, in *ReadHomeTimelineRequest, opts ...grpc.CallOption) (*ReadHomeTimelineResponse, error)
	WriteHomeTimeline(ctx context.Context, in *WriteHomeTimelineRequest, opts ...grpc.CallOption) (*WriteHomeTimelineResponse, error)
}

HomeTimelineClient is the client API for HomeTimeline service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type HomeTimelineServer

type HomeTimelineServer interface {
	ReadHomeTimeline(context.Context, *ReadHomeTimelineRequest) (*ReadHomeTimelineResponse, error)
	WriteHomeTimeline(context.Context, *WriteHomeTimelineRequest) (*WriteHomeTimelineResponse, error)
	// contains filtered or unexported methods
}

HomeTimelineServer is the server API for HomeTimeline service. All implementations must embed UnimplementedHomeTimelineServer for forward compatibility

type InsertUserRequest

type InsertUserRequest struct {
	UserId string `protobuf:"bytes,1,opt,name=user_id,json=userId,proto3" json:"user_id,omitempty"`
	// contains filtered or unexported fields
}

func (*InsertUserRequest) Descriptor deprecated

func (*InsertUserRequest) Descriptor() ([]byte, []int)

Deprecated: Use InsertUserRequest.ProtoReflect.Descriptor instead.

func (*InsertUserRequest) GetUserId

func (x *InsertUserRequest) GetUserId() string

func (*InsertUserRequest) ProtoMessage

func (*InsertUserRequest) ProtoMessage()

func (*InsertUserRequest) ProtoReflect

func (x *InsertUserRequest) ProtoReflect() protoreflect.Message

func (*InsertUserRequest) Reset

func (x *InsertUserRequest) Reset()

func (*InsertUserRequest) String

func (x *InsertUserRequest) String() string

type InsertUserResponse

type InsertUserResponse struct {
	Success bool `protobuf:"varint,1,opt,name=success,proto3" json:"success,omitempty"`
	// contains filtered or unexported fields
}

func (*InsertUserResponse) Descriptor deprecated

func (*InsertUserResponse) Descriptor() ([]byte, []int)

Deprecated: Use InsertUserResponse.ProtoReflect.Descriptor instead.

func (*InsertUserResponse) GetSuccess

func (x *InsertUserResponse) GetSuccess() bool

func (*InsertUserResponse) ProtoMessage

func (*InsertUserResponse) ProtoMessage()

func (*InsertUserResponse) ProtoReflect

func (x *InsertUserResponse) ProtoReflect() protoreflect.Message

func (*InsertUserResponse) Reset

func (x *InsertUserResponse) Reset()

func (*InsertUserResponse) String

func (x *InsertUserResponse) String() string

type NginxServiceClient

type NginxServiceClient interface {
	ComposePost(ctx context.Context, in *ComposePostRequest, opts ...grpc.CallOption) (*ComposePostResponse, error)
	ReadUserTimeline(ctx context.Context, in *ReadUserTimelineRequest, opts ...grpc.CallOption) (*ReadUserTimelineResponse, error)
	ReadHomeTimeline(ctx context.Context, in *ReadHomeTimelineRequest, opts ...grpc.CallOption) (*ReadHomeTimelineResponse, error)
}

NginxServiceClient is the client API for NginxService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type NginxServiceServer

type NginxServiceServer interface {
	ComposePost(context.Context, *ComposePostRequest) (*ComposePostResponse, error)
	ReadUserTimeline(context.Context, *ReadUserTimelineRequest) (*ReadUserTimelineResponse, error)
	ReadHomeTimeline(context.Context, *ReadHomeTimelineRequest) (*ReadHomeTimelineResponse, error)
	// contains filtered or unexported methods
}

NginxServiceServer is the server API for NginxService service. All implementations must embed UnimplementedNginxServiceServer for forward compatibility

type Post

type Post struct {
	PostId    string `protobuf:"bytes,1,opt,name=post_id,json=postId,proto3" json:"post_id,omitempty"`
	Timestamp int64  `protobuf:"varint,4,opt,name=timestamp,proto3" json:"timestamp,omitempty"`
	Text      string `protobuf:"bytes,2,opt,name=text,proto3" json:"text,omitempty"`
	CreatorId string `protobuf:"bytes,3,opt,name=creator_id,json=creatorId,proto3" json:"creator_id,omitempty"`
	// contains filtered or unexported fields
}

func (*Post) Descriptor deprecated

func (*Post) Descriptor() ([]byte, []int)

Deprecated: Use Post.ProtoReflect.Descriptor instead.

func (*Post) GetCreatorId

func (x *Post) GetCreatorId() string

func (*Post) GetPostId

func (x *Post) GetPostId() string

func (*Post) GetText

func (x *Post) GetText() string

func (*Post) GetTimestamp

func (x *Post) GetTimestamp() int64

func (*Post) ProtoMessage

func (*Post) ProtoMessage()

func (*Post) ProtoReflect

func (x *Post) ProtoReflect() protoreflect.Message

func (*Post) Reset

func (x *Post) Reset()

func (*Post) String

func (x *Post) String() string

type PostStorageClient

type PostStorageClient interface {
	StorePost(ctx context.Context, in *StorePostRequest, opts ...grpc.CallOption) (*StorePostResponse, error)
	StorePostMulti(ctx context.Context, in *StorePostMultiRequest, opts ...grpc.CallOption) (*StorePostMultiResponse, error)
	ReadPost(ctx context.Context, in *ReadPostRequest, opts ...grpc.CallOption) (*ReadPostResponse, error)
	ReadPosts(ctx context.Context, in *ReadPostsRequest, opts ...grpc.CallOption) (*ReadPostsResponse, error)
}

PostStorageClient is the client API for PostStorage service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type PostStorageServer

type PostStorageServer interface {
	StorePost(context.Context, *StorePostRequest) (*StorePostResponse, error)
	StorePostMulti(context.Context, *StorePostMultiRequest) (*StorePostMultiResponse, error)
	ReadPost(context.Context, *ReadPostRequest) (*ReadPostResponse, error)
	ReadPosts(context.Context, *ReadPostsRequest) (*ReadPostsResponse, error)
	// contains filtered or unexported methods
}

PostStorageServer is the server API for PostStorage service. All implementations must embed UnimplementedPostStorageServer for forward compatibility

type ReadHomeTimelineRequest

type ReadHomeTimelineRequest struct {
	UserId string `protobuf:"bytes,1,opt,name=user_id,json=userId,proto3" json:"user_id,omitempty"`
	// contains filtered or unexported fields
}

func (*ReadHomeTimelineRequest) Descriptor deprecated

func (*ReadHomeTimelineRequest) Descriptor() ([]byte, []int)

Deprecated: Use ReadHomeTimelineRequest.ProtoReflect.Descriptor instead.

func (*ReadHomeTimelineRequest) GetUserId

func (x *ReadHomeTimelineRequest) GetUserId() string

func (*ReadHomeTimelineRequest) ProtoMessage

func (*ReadHomeTimelineRequest) ProtoMessage()

func (*ReadHomeTimelineRequest) ProtoReflect

func (x *ReadHomeTimelineRequest) ProtoReflect() protoreflect.Message

func (*ReadHomeTimelineRequest) Reset

func (x *ReadHomeTimelineRequest) Reset()

func (*ReadHomeTimelineRequest) String

func (x *ReadHomeTimelineRequest) String() string

type ReadHomeTimelineResponse

type ReadHomeTimelineResponse struct {
	Posts []*Post `protobuf:"bytes,1,rep,name=posts,proto3" json:"posts,omitempty"`
	// contains filtered or unexported fields
}

func (*ReadHomeTimelineResponse) Descriptor deprecated

func (*ReadHomeTimelineResponse) Descriptor() ([]byte, []int)

Deprecated: Use ReadHomeTimelineResponse.ProtoReflect.Descriptor instead.

func (*ReadHomeTimelineResponse) GetPosts

func (x *ReadHomeTimelineResponse) GetPosts() []*Post

func (*ReadHomeTimelineResponse) ProtoMessage

func (*ReadHomeTimelineResponse) ProtoMessage()

func (*ReadHomeTimelineResponse) ProtoReflect

func (x *ReadHomeTimelineResponse) ProtoReflect() protoreflect.Message

func (*ReadHomeTimelineResponse) Reset

func (x *ReadHomeTimelineResponse) Reset()

func (*ReadHomeTimelineResponse) String

func (x *ReadHomeTimelineResponse) String() string

type ReadPostRequest

type ReadPostRequest struct {
	PostId string `protobuf:"bytes,1,opt,name=post_id,json=postId,proto3" json:"post_id,omitempty"`
	// contains filtered or unexported fields
}

func (*ReadPostRequest) Descriptor deprecated

func (*ReadPostRequest) Descriptor() ([]byte, []int)

Deprecated: Use ReadPostRequest.ProtoReflect.Descriptor instead.

func (*ReadPostRequest) GetPostId

func (x *ReadPostRequest) GetPostId() string

func (*ReadPostRequest) ProtoMessage

func (*ReadPostRequest) ProtoMessage()

func (*ReadPostRequest) ProtoReflect

func (x *ReadPostRequest) ProtoReflect() protoreflect.Message

func (*ReadPostRequest) Reset

func (x *ReadPostRequest) Reset()

func (*ReadPostRequest) String

func (x *ReadPostRequest) String() string

type ReadPostResponse

type ReadPostResponse struct {
	Post *Post `protobuf:"bytes,1,opt,name=post,proto3" json:"post,omitempty"`
	// contains filtered or unexported fields
}

func (*ReadPostResponse) Descriptor deprecated

func (*ReadPostResponse) Descriptor() ([]byte, []int)

Deprecated: Use ReadPostResponse.ProtoReflect.Descriptor instead.

func (*ReadPostResponse) GetPost

func (x *ReadPostResponse) GetPost() *Post

func (*ReadPostResponse) ProtoMessage

func (*ReadPostResponse) ProtoMessage()

func (*ReadPostResponse) ProtoReflect

func (x *ReadPostResponse) ProtoReflect() protoreflect.Message

func (*ReadPostResponse) Reset

func (x *ReadPostResponse) Reset()

func (*ReadPostResponse) String

func (x *ReadPostResponse) String() string

type ReadPostsRequest

type ReadPostsRequest struct {
	PostIds []string `protobuf:"bytes,1,rep,name=post_ids,json=postIds,proto3" json:"post_ids,omitempty"`
	// contains filtered or unexported fields
}

func (*ReadPostsRequest) Descriptor deprecated

func (*ReadPostsRequest) Descriptor() ([]byte, []int)

Deprecated: Use ReadPostsRequest.ProtoReflect.Descriptor instead.

func (*ReadPostsRequest) GetPostIds

func (x *ReadPostsRequest) GetPostIds() []string

func (*ReadPostsRequest) ProtoMessage

func (*ReadPostsRequest) ProtoMessage()

func (*ReadPostsRequest) ProtoReflect

func (x *ReadPostsRequest) ProtoReflect() protoreflect.Message

func (*ReadPostsRequest) Reset

func (x *ReadPostsRequest) Reset()

func (*ReadPostsRequest) String

func (x *ReadPostsRequest) String() string

type ReadPostsResponse

type ReadPostsResponse struct {
	Posts []*Post `protobuf:"bytes,1,rep,name=posts,proto3" json:"posts,omitempty"`
	// contains filtered or unexported fields
}

func (*ReadPostsResponse) Descriptor deprecated

func (*ReadPostsResponse) Descriptor() ([]byte, []int)

Deprecated: Use ReadPostsResponse.ProtoReflect.Descriptor instead.

func (*ReadPostsResponse) GetPosts

func (x *ReadPostsResponse) GetPosts() []*Post

func (*ReadPostsResponse) ProtoMessage

func (*ReadPostsResponse) ProtoMessage()

func (*ReadPostsResponse) ProtoReflect

func (x *ReadPostsResponse) ProtoReflect() protoreflect.Message

func (*ReadPostsResponse) Reset

func (x *ReadPostsResponse) Reset()

func (*ReadPostsResponse) String

func (x *ReadPostsResponse) String() string

type ReadUserTimelineRequest

type ReadUserTimelineRequest struct {
	UserId string `protobuf:"bytes,1,opt,name=user_id,json=userId,proto3" json:"user_id,omitempty"`
	// contains filtered or unexported fields
}

func (*ReadUserTimelineRequest) Descriptor deprecated

func (*ReadUserTimelineRequest) Descriptor() ([]byte, []int)

Deprecated: Use ReadUserTimelineRequest.ProtoReflect.Descriptor instead.

func (*ReadUserTimelineRequest) GetUserId

func (x *ReadUserTimelineRequest) GetUserId() string

func (*ReadUserTimelineRequest) ProtoMessage

func (*ReadUserTimelineRequest) ProtoMessage()

func (*ReadUserTimelineRequest) ProtoReflect

func (x *ReadUserTimelineRequest) ProtoReflect() protoreflect.Message

func (*ReadUserTimelineRequest) Reset

func (x *ReadUserTimelineRequest) Reset()

func (*ReadUserTimelineRequest) String

func (x *ReadUserTimelineRequest) String() string

type ReadUserTimelineResponse

type ReadUserTimelineResponse struct {
	Posts []*Post `protobuf:"bytes,1,rep,name=posts,proto3" json:"posts,omitempty"`
	// contains filtered or unexported fields
}

func (*ReadUserTimelineResponse) Descriptor deprecated

func (*ReadUserTimelineResponse) Descriptor() ([]byte, []int)

Deprecated: Use ReadUserTimelineResponse.ProtoReflect.Descriptor instead.

func (*ReadUserTimelineResponse) GetPosts

func (x *ReadUserTimelineResponse) GetPosts() []*Post

func (*ReadUserTimelineResponse) ProtoMessage

func (*ReadUserTimelineResponse) ProtoMessage()

func (*ReadUserTimelineResponse) ProtoReflect

func (x *ReadUserTimelineResponse) ProtoReflect() protoreflect.Message

func (*ReadUserTimelineResponse) Reset

func (x *ReadUserTimelineResponse) Reset()

func (*ReadUserTimelineResponse) String

func (x *ReadUserTimelineResponse) String() string

type SocialGraphClient

type SocialGraphClient interface {
	InsertUser(ctx context.Context, in *InsertUserRequest, opts ...grpc.CallOption) (*InsertUserResponse, error)
	GetFollowers(ctx context.Context, in *GetFollowersRequest, opts ...grpc.CallOption) (*GetFollowersResponse, error)
	GetFollowees(ctx context.Context, in *GetFolloweesRequest, opts ...grpc.CallOption) (*GetFolloweesResponse, error)
	Follow(ctx context.Context, in *FollowRequest, opts ...grpc.CallOption) (*FollowResponse, error)
	FollowMany(ctx context.Context, in *FollowManyRequest, opts ...grpc.CallOption) (*FollowManyResponse, error)
}

SocialGraphClient is the client API for SocialGraph service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type SocialGraphServer

type SocialGraphServer interface {
	InsertUser(context.Context, *InsertUserRequest) (*InsertUserResponse, error)
	GetFollowers(context.Context, *GetFollowersRequest) (*GetFollowersResponse, error)
	GetFollowees(context.Context, *GetFolloweesRequest) (*GetFolloweesResponse, error)
	Follow(context.Context, *FollowRequest) (*FollowResponse, error)
	FollowMany(context.Context, *FollowManyRequest) (*FollowManyResponse, error)
	// contains filtered or unexported methods
}

SocialGraphServer is the server API for SocialGraph service. All implementations must embed UnimplementedSocialGraphServer for forward compatibility

type StorePostMultiRequest

type StorePostMultiRequest struct {
	Text      string `protobuf:"bytes,1,opt,name=text,proto3" json:"text,omitempty"`
	CreatorId string `protobuf:"bytes,2,opt,name=creator_id,json=creatorId,proto3" json:"creator_id,omitempty"`
	Number    int32  `protobuf:"varint,3,opt,name=number,proto3" json:"number,omitempty"`
	// contains filtered or unexported fields
}

func (*StorePostMultiRequest) Descriptor deprecated

func (*StorePostMultiRequest) Descriptor() ([]byte, []int)

Deprecated: Use StorePostMultiRequest.ProtoReflect.Descriptor instead.

func (*StorePostMultiRequest) GetCreatorId

func (x *StorePostMultiRequest) GetCreatorId() string

func (*StorePostMultiRequest) GetNumber

func (x *StorePostMultiRequest) GetNumber() int32

func (*StorePostMultiRequest) GetText

func (x *StorePostMultiRequest) GetText() string

func (*StorePostMultiRequest) ProtoMessage

func (*StorePostMultiRequest) ProtoMessage()

func (*StorePostMultiRequest) ProtoReflect

func (x *StorePostMultiRequest) ProtoReflect() protoreflect.Message

func (*StorePostMultiRequest) Reset

func (x *StorePostMultiRequest) Reset()

func (*StorePostMultiRequest) String

func (x *StorePostMultiRequest) String() string

type StorePostMultiResponse

type StorePostMultiResponse struct {
	PostIds []string `protobuf:"bytes,1,rep,name=post_ids,json=postIds,proto3" json:"post_ids,omitempty"`
	// contains filtered or unexported fields
}

func (*StorePostMultiResponse) Descriptor deprecated

func (*StorePostMultiResponse) Descriptor() ([]byte, []int)

Deprecated: Use StorePostMultiResponse.ProtoReflect.Descriptor instead.

func (*StorePostMultiResponse) GetPostIds

func (x *StorePostMultiResponse) GetPostIds() []string

func (*StorePostMultiResponse) ProtoMessage

func (*StorePostMultiResponse) ProtoMessage()

func (*StorePostMultiResponse) ProtoReflect

func (x *StorePostMultiResponse) ProtoReflect() protoreflect.Message

func (*StorePostMultiResponse) Reset

func (x *StorePostMultiResponse) Reset()

func (*StorePostMultiResponse) String

func (x *StorePostMultiResponse) String() string

type StorePostRequest

type StorePostRequest struct {
	Text      string `protobuf:"bytes,1,opt,name=text,proto3" json:"text,omitempty"`
	CreatorId string `protobuf:"bytes,2,opt,name=creator_id,json=creatorId,proto3" json:"creator_id,omitempty"`
	// contains filtered or unexported fields
}

func (*StorePostRequest) Descriptor deprecated

func (*StorePostRequest) Descriptor() ([]byte, []int)

Deprecated: Use StorePostRequest.ProtoReflect.Descriptor instead.

func (*StorePostRequest) GetCreatorId

func (x *StorePostRequest) GetCreatorId() string

func (*StorePostRequest) GetText

func (x *StorePostRequest) GetText() string

func (*StorePostRequest) ProtoMessage

func (*StorePostRequest) ProtoMessage()

func (*StorePostRequest) ProtoReflect

func (x *StorePostRequest) ProtoReflect() protoreflect.Message

func (*StorePostRequest) Reset

func (x *StorePostRequest) Reset()

func (*StorePostRequest) String

func (x *StorePostRequest) String() string

type StorePostResponse

type StorePostResponse struct {
	PostId string `protobuf:"bytes,1,opt,name=post_id,json=postId,proto3" json:"post_id,omitempty"`
	// contains filtered or unexported fields
}

func (*StorePostResponse) Descriptor deprecated

func (*StorePostResponse) Descriptor() ([]byte, []int)

Deprecated: Use StorePostResponse.ProtoReflect.Descriptor instead.

func (*StorePostResponse) GetPostId

func (x *StorePostResponse) GetPostId() string

func (*StorePostResponse) ProtoMessage

func (*StorePostResponse) ProtoMessage()

func (*StorePostResponse) ProtoReflect

func (x *StorePostResponse) ProtoReflect() protoreflect.Message

func (*StorePostResponse) Reset

func (x *StorePostResponse) Reset()

func (*StorePostResponse) String

func (x *StorePostResponse) String() string

type UnimplementedComposePostServer

type UnimplementedComposePostServer struct {
}

UnimplementedComposePostServer must be embedded to have forward compatible implementations.

func (UnimplementedComposePostServer) ComposePost

func (UnimplementedComposePostServer) ComposePostMulti

type UnimplementedHomeTimelineServer

type UnimplementedHomeTimelineServer struct {
}

UnimplementedHomeTimelineServer must be embedded to have forward compatible implementations.

func (UnimplementedHomeTimelineServer) ReadHomeTimeline

func (UnimplementedHomeTimelineServer) WriteHomeTimeline

type UnimplementedNginxServiceServer

type UnimplementedNginxServiceServer struct {
}

UnimplementedNginxServiceServer must be embedded to have forward compatible implementations.

func (UnimplementedNginxServiceServer) ComposePost

func (UnimplementedNginxServiceServer) ReadHomeTimeline

func (UnimplementedNginxServiceServer) ReadUserTimeline

type UnimplementedPostStorageServer

type UnimplementedPostStorageServer struct {
}

UnimplementedPostStorageServer must be embedded to have forward compatible implementations.

func (UnimplementedPostStorageServer) ReadPost

func (UnimplementedPostStorageServer) ReadPosts

func (UnimplementedPostStorageServer) StorePost

func (UnimplementedPostStorageServer) StorePostMulti

type UnimplementedSocialGraphServer

type UnimplementedSocialGraphServer struct {
}

UnimplementedSocialGraphServer must be embedded to have forward compatible implementations.

func (UnimplementedSocialGraphServer) Follow

func (UnimplementedSocialGraphServer) FollowMany

func (UnimplementedSocialGraphServer) GetFollowees

func (UnimplementedSocialGraphServer) GetFollowers

func (UnimplementedSocialGraphServer) InsertUser

type UnimplementedUserTimelineServer

type UnimplementedUserTimelineServer struct {
}

UnimplementedUserTimelineServer must be embedded to have forward compatible implementations.

func (UnimplementedUserTimelineServer) ReadUserTimeline

func (UnimplementedUserTimelineServer) WriteUserTimeline

type UnsafeComposePostServer

type UnsafeComposePostServer interface {
	// contains filtered or unexported methods
}

UnsafeComposePostServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ComposePostServer will result in compilation errors.

type UnsafeHomeTimelineServer

type UnsafeHomeTimelineServer interface {
	// contains filtered or unexported methods
}

UnsafeHomeTimelineServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to HomeTimelineServer will result in compilation errors.

type UnsafeNginxServiceServer

type UnsafeNginxServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeNginxServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to NginxServiceServer will result in compilation errors.

type UnsafePostStorageServer

type UnsafePostStorageServer interface {
	// contains filtered or unexported methods
}

UnsafePostStorageServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to PostStorageServer will result in compilation errors.

type UnsafeSocialGraphServer

type UnsafeSocialGraphServer interface {
	// contains filtered or unexported methods
}

UnsafeSocialGraphServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to SocialGraphServer will result in compilation errors.

type UnsafeUserTimelineServer

type UnsafeUserTimelineServer interface {
	// contains filtered or unexported methods
}

UnsafeUserTimelineServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to UserTimelineServer will result in compilation errors.

type UserTimelineClient

type UserTimelineClient interface {
	ReadUserTimeline(ctx context.Context, in *ReadUserTimelineRequest, opts ...grpc.CallOption) (*ReadUserTimelineResponse, error)
	WriteUserTimeline(ctx context.Context, in *WriteUserTimelineRequest, opts ...grpc.CallOption) (*WriteUserTimelineResponse, error)
}

UserTimelineClient is the client API for UserTimeline service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type UserTimelineServer

type UserTimelineServer interface {
	ReadUserTimeline(context.Context, *ReadUserTimelineRequest) (*ReadUserTimelineResponse, error)
	WriteUserTimeline(context.Context, *WriteUserTimelineRequest) (*WriteUserTimelineResponse, error)
	// contains filtered or unexported methods
}

UserTimelineServer is the server API for UserTimeline service. All implementations must embed UnimplementedUserTimelineServer for forward compatibility

type WriteHomeTimelineRequest

type WriteHomeTimelineRequest struct {
	UserId  string   `protobuf:"bytes,1,opt,name=user_id,json=userId,proto3" json:"user_id,omitempty"`
	PostIds []string `protobuf:"bytes,2,rep,name=post_ids,json=postIds,proto3" json:"post_ids,omitempty"`
	// contains filtered or unexported fields
}

func (*WriteHomeTimelineRequest) Descriptor deprecated

func (*WriteHomeTimelineRequest) Descriptor() ([]byte, []int)

Deprecated: Use WriteHomeTimelineRequest.ProtoReflect.Descriptor instead.

func (*WriteHomeTimelineRequest) GetPostIds

func (x *WriteHomeTimelineRequest) GetPostIds() []string

func (*WriteHomeTimelineRequest) GetUserId

func (x *WriteHomeTimelineRequest) GetUserId() string

func (*WriteHomeTimelineRequest) ProtoMessage

func (*WriteHomeTimelineRequest) ProtoMessage()

func (*WriteHomeTimelineRequest) ProtoReflect

func (x *WriteHomeTimelineRequest) ProtoReflect() protoreflect.Message

func (*WriteHomeTimelineRequest) Reset

func (x *WriteHomeTimelineRequest) Reset()

func (*WriteHomeTimelineRequest) String

func (x *WriteHomeTimelineRequest) String() string

type WriteHomeTimelineResponse

type WriteHomeTimelineResponse struct {
	Success bool `protobuf:"varint,1,opt,name=success,proto3" json:"success,omitempty"`
	// contains filtered or unexported fields
}

func (*WriteHomeTimelineResponse) Descriptor deprecated

func (*WriteHomeTimelineResponse) Descriptor() ([]byte, []int)

Deprecated: Use WriteHomeTimelineResponse.ProtoReflect.Descriptor instead.

func (*WriteHomeTimelineResponse) GetSuccess

func (x *WriteHomeTimelineResponse) GetSuccess() bool

func (*WriteHomeTimelineResponse) ProtoMessage

func (*WriteHomeTimelineResponse) ProtoMessage()

func (*WriteHomeTimelineResponse) ProtoReflect

func (*WriteHomeTimelineResponse) Reset

func (x *WriteHomeTimelineResponse) Reset()

func (*WriteHomeTimelineResponse) String

func (x *WriteHomeTimelineResponse) String() string

type WriteUserTimelineRequest

type WriteUserTimelineRequest struct {
	UserId  string   `protobuf:"bytes,1,opt,name=user_id,json=userId,proto3" json:"user_id,omitempty"`
	PostIds []string `protobuf:"bytes,2,rep,name=post_ids,json=postIds,proto3" json:"post_ids,omitempty"`
	// contains filtered or unexported fields
}

func (*WriteUserTimelineRequest) Descriptor deprecated

func (*WriteUserTimelineRequest) Descriptor() ([]byte, []int)

Deprecated: Use WriteUserTimelineRequest.ProtoReflect.Descriptor instead.

func (*WriteUserTimelineRequest) GetPostIds

func (x *WriteUserTimelineRequest) GetPostIds() []string

func (*WriteUserTimelineRequest) GetUserId

func (x *WriteUserTimelineRequest) GetUserId() string

func (*WriteUserTimelineRequest) ProtoMessage

func (*WriteUserTimelineRequest) ProtoMessage()

func (*WriteUserTimelineRequest) ProtoReflect

func (x *WriteUserTimelineRequest) ProtoReflect() protoreflect.Message

func (*WriteUserTimelineRequest) Reset

func (x *WriteUserTimelineRequest) Reset()

func (*WriteUserTimelineRequest) String

func (x *WriteUserTimelineRequest) String() string

type WriteUserTimelineResponse

type WriteUserTimelineResponse struct {
	Success bool `protobuf:"varint,1,opt,name=success,proto3" json:"success,omitempty"`
	// contains filtered or unexported fields
}

func (*WriteUserTimelineResponse) Descriptor deprecated

func (*WriteUserTimelineResponse) Descriptor() ([]byte, []int)

Deprecated: Use WriteUserTimelineResponse.ProtoReflect.Descriptor instead.

func (*WriteUserTimelineResponse) GetSuccess

func (x *WriteUserTimelineResponse) GetSuccess() bool

func (*WriteUserTimelineResponse) ProtoMessage

func (*WriteUserTimelineResponse) ProtoMessage()

func (*WriteUserTimelineResponse) ProtoReflect

func (*WriteUserTimelineResponse) Reset

func (x *WriteUserTimelineResponse) Reset()

func (*WriteUserTimelineResponse) String

func (x *WriteUserTimelineResponse) String() string

Jump to